{ pkgs
, lib
, config
, ... }: with lib; let
  terminal = toString pkgs.alacritty;
in mkIf config.passthrough.gui {
  wayland.windowManager.sway = {
    enable = true;
    config = {
      modifier = "Mod4";
      menu = "wofi -show drun -modi drun";

      keybindings = let
        modifier = config.wayland.windowManager.sway.config.modifier;
      in mkOptionDefault {
        XF86MonBrightnessUp = "light -A 5";
        XF86MonBrightnessDown = "light -U 5";

        "Control+Alt+l" = "${pkgs.swaylock}/bin/swaylock -c 000000";
        "Print" = "exec ${pkgs.grim}/bin/grim - | ${pkgs.wl-clipboard}/bin/wl-copy";
        "${modifier}+Print" = "exec ${pkgs.grim}/bin/grim -g \"$(${pkgs.slurp}/bin/slurp)\" - | ${pkgs.wl-clipboard}/bin/wl-copy";
        "${modifier}+q" = "exec google-chrome-stable";
      };

      input."*".natural_scroll = "enabled";
      input."type:touchpad".tap = "enabled";
      output."*".bg = "${../../share/54345906_p0.jpg} fill";
    };
  };

  # application menu setup
  programs.wofi = {
    enable = true;
    settings.mode = "drun";
    settings.allow_images = true;
  };

  # cursor theme
  home.pointerCursor = {
    package = pkgs.bibata-cursors;
    name = "Bibata-Modern-Classic";
    size = 24;
  };

  # gtk theme
  gtk.theme = {
    package = pkgs.whitesur-gtk-theme;
    name = "WhiteSur-Dark";
  };

  # gtk icons
  gtk.iconTheme = {
    package = pkgs.whitesur-icon-theme;
    name = "WhiteSur-dark";
  };

  gtk.enable = true;
}
